function []=PrintPointPredEval(RMSE,MAE,MAPE,MPE,LogDetMSSE,TraceMSSE,MSSESubsetVars,VarLabels,ModelLabels,EvalHorizons,PrintHorizons,PrintMeasures,PrintVars,PrintModels,PrintMSSESubsets,OutFileName)

DateAndTimeStr=Clock2DateAndTimeStr(clock);     % a string containing current data and time    
fid=fopen(strcat(OutFileName,'.txt'),'wt'); % Open file to write the results to

AllUniMeasures(:,:,:,1)=RMSE;
AllUniMeasures(:,:,:,2)=MAE;
AllUniMeasures(:,:,:,3)=MAPE;
AllUniMeasures(:,:,:,4)=MPE;
AllMultiMeasures{1}=LogDetMSSE;
AllMultiMeasures{2}=TraceMSSE;

MeasureLabels{1}='RMSE';
MeasureLabels{2}='MAE';
MeasureLabels{3}='MAPE';
MeasureLabels{4}='MPE';
MultiMeasureLabels={'Log Determinant MSSE matrix','Trace MSSE Matrix'};
PrintMultiMeasures=[1 2]; % LogDet and Trace
NUniMeasures=length(PrintMeasures);
NModels=length(PrintModels);
NPrintVars=length(PrintVars);
NMSSESubsets=length(MSSESubsetVars);
NPrintHorizons=length(PrintHorizons);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%       Printing routine for univariate forecasting measures        %%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


fprintf(fid,'\n');
fprintf(fid,'--------------------------------------------------------------------------------------------------------------------\n');
fprintf(fid,'                                      Measures of Point Forecast Accuracy                                           \n');
fprintf(fid,'                         Author: Mattias Villani, Sveriges Riksbank and Stockholm University                        \n');
fprintf(fid,['                                               ',DateAndTimeStr,'                            \n']);
fprintf(fid,'--------------------------------------------------------------------------------------------------------------------\n');

%%%%%%%%%%%%%%%%%% Univariate measures %%%%%%%%%%%%%%%%%%%%
for Measure=PrintMeasures
    fprintf(fid,'\n\n\n');
    fprintf(fid,'---------------------------------------------------------------------\n');
    fprintf(fid,['                         ',MeasureLabels{Measure},'                 \n']);
    fprintf(fid,'---------------------------------------------------------------------\n');
    
    for Model=PrintModels
        fprintf(fid,'\n');
        fprintf(fid,ModelLabels{Model});
        fprintf(fid,'\n');
        
        % Printing variable labels on top of each column
        fprintf(fid,'%7.7s','Horizon');
        for Var=PrintVars
            fprintf(fid,'%10.10s',VarLabels{Var});
        end
        fprintf(fid,'\n');
        
        % Printing Univariate forecast accuracy measures
        for h=1:NPrintHorizons
            fprintf(fid,'%7s',strcat(int2str(EvalHorizons(h)),'Q'));
            fprintf(fid,'%10.3f',AllUniMeasures(h,PrintVars,Model,Measure));
            fprintf(fid,'\n');
        end
    end
end


%%%%%%%%%%%%%% Multivariate Measures %%%%%%%%%%%%%
for u=PrintMSSESubsets
    CurrentSubsetVars=VarLabels(MSSESubsetVars{u});
    StrCurrentSubsetVars='';
    for r=1:length(CurrentSubsetVars)
        StrCurrentSubsetVars=[StrCurrentSubsetVars,CurrentSubsetVars{r},', '];
    end
    StrCurrentSubsetVars=StrCurrentSubsetVars(1:end-2);
    fprintf(fid,'\n\n\n\n');
    fprintf(fid,['MULTIVARIATE MEASURES OF FORECAST ACCURACY FOR: ',StrCurrentSubsetVars,'\n']);
    
    for Measure=PrintMultiMeasures
        fprintf(fid,'\n');
        fprintf(fid,[MultiMeasureLabels{Measure},'\n']);
        fprintf(fid,'%7.7s','Horizon');
        for Model=PrintModels            
            fprintf(fid,'%15.10s',ModelLabels{Model});
        end
        fprintf(fid,'\n');
        
        % Printing Multivariate forecast accuracy measures
        for h=1:NPrintHorizons
            fprintf(fid,'%7s',strcat(int2str(EvalHorizons(h)),'Q'));
            for Model=PrintModels            
                fprintf(fid,'%15.3f',AllMultiMeasures{Measure}(h,u,Model));
            end
            fprintf(fid,'\n');
        end
    end
end


fclose(fid);
winopen(strcat(OutFileName,'.txt'))